@@ -111,6 +111,7 @@ clinicaltrials_gov_download <- function(
             responsible_party = character(),
             lead_sponsor = character(),
             collaborators = character(),
+            locations = character(),
             whystopped = character(),
             results_posted = character(),
             references = character(),
@@ -248,6 +249,7 @@ clinicaltrials_gov_download <- function(
                             ~responsible_party,
                             ~lead_sponsor,
                             ~collaborator,
+                            ~locations,
                             ~whystopped,
                             ~results_posted,
                             ~references,
@@ -276,6 +278,7 @@ clinicaltrials_gov_download <- function(
                             versiondata$responsible_party,
                             versiondata$lead_sponsor,
                             versiondata$collaborators,
+                            versiondata$locations,
                             versiondata$whystopped,
                             versiondata$results_posted,
                             versiondata$references,
